API Summary
===========

This contains a summary of the "public" API exposed by the project. Click on
each object for full API definitions.

The public classes are:

.. automodsumm:: tkmilan
   :classes-only:
   :nosignatures:

.. TODO No functions exposed yet

.. The public functions are:

.. .. automodsumm:: tkmilan
..    :functions-only:
..    :nosignatures:

The public variables are:

.. automodsumm:: tkmilan
   :variables-only:
   :nosignatures:
   :skip: logger

This results in the following class diagram:

.. automod-diagram:: tkmilan
   :private-bases:
